@@ -3,7 +3,7 @@ use Moose::Role;
 use CatalystX::InjectComponent;
 use namespace::autoclean;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 after 'setup_components' => sub {
     my $class = shift;
@@ -51,8 +51,8 @@ using this code. Come back here when you're done there.
 
 =head1 DESCRIPTION
 
-CatalystX::SimpleLogin is an application class L<Moose::Role|role> which will
-inject a L<Catalyst::Controller|controller>
+CatalystX::SimpleLogin is an application class L<Moose::Role> which will
+inject a L<Catalyst::Controller>
 which is an instance of L<CatalystX::SimpleLogin::Controller::Login> into your
 application. This provides a simple login and logout page with the adition
 of only one line of code and one template to your application.
@@ -100,7 +100,7 @@ logout actions or override methods.
 
 =item *
 
-L<CatalystX::SimpleLogin::TraitFor::Controller::Logout> - provides the C<logout> action
+L<CatalystX::SimpleLogin::TraitFor::Controller::Login::Logout> - provides the C<logout> action
 and associated methods. You can compose this manually yourself if you want just that
 action.
 
@@ -173,7 +173,7 @@ L<Moose> and L<Moose::Role>
 
 =item *
 
-L<MooseX::MethodAttributes::Role> - Actions compsed from L<Moose::Role|Roles>.
+L<MooseX::MethodAttributes::Role> - Actions composed from L<Moose::Role>.
 
 =item *
 
@@ -205,11 +205,11 @@ L<CatalystX::Component::Traits> - Allows L<Moose::Role|roles> to be composed ont
 
 =over
 
-=item Tomas Doran (t0m) C<< <bobtfish@bobtfish.net> >>
+=item Tomas Doran (t0m) C<< bobtfish@bobtfish.net >>
 
 =item Zbigniew Lukasiak
 
-=item Stephan Jauernick (stephan48) C<< <stephan@stejau.de> >>
+=item Stephan Jauernick (stephan48) C<< stephan@stejau.de >>
 
 =item Gerda Shank (gshank) C<< gshank@cpan.org >>
 
@@ -217,6 +217,8 @@ L<CatalystX::Component::Traits> - Allows L<Moose::Role|roles> to be composed ont
 
 =item Shlomi Fish
 
+=item Oleg Kostyuk (cub-uanic) C<< cub@cpan.org >>
+
 =back
 
 =head1 LICENSE
