@@ -15,5 +15,4 @@ __PACKAGE__->config(
 
 __PACKAGE__->setup;
 
-__PACKAGE__->meta->make_immutable( replace_constructor => 1 );
-
+1;
